* VERSION 1.3
* FIRST VERSION: MAR 02, 2006
* THIS VERSION:  JUN 19, 2006
* LAST REVISOR: SOB
*

# delimit ;

capture log close;
clear;

cd "$rootcafe";
log using "logs/displacement-psmatch2-hetero-$par.log", replace;
adopath + "$root/%stata/ado"; 

set matsize 800;
set more off;
set rmsg on;
set seed 1234;

capture mkdir "$rootcafe/estmat/$par";
capture mkdir "$rootcafe/Xdata/$par";

*-----------------------------------------------;
capture program drop memuse;
program define memuse;
   qui memory;
   local memused = round(_N * `r(width)' / (1024*1024));
   local memsize = round(`r(M_total)' / (1024*1024));
   display in ye "`memused' MB of `memsize' MB allocated memory in use";
end;
*-----------------------------------------------;
capture program drop resultsor;
program define resultsor;
   args matnam;
	local matnam = trim(subinstr("`matnam'",",","",.));
   est2vec `matnam', e(r2_p);
   mat b=e(b)';
   local names : rownames b;
   local rowtot = rowsof(b);
   mat v=vecdiag(e(V))';
   svmat b;
   svmat v;
   qui gen or=exp(b1);
   mkmat or if _n<=`rowtot', matrix(`matnam'_b); /* automatically replaces vector b */
   matrix rownames `matnam'_b = `names';
   matrix colnames `matnam'_b = `e(depvar)';
   qui gen se = or*sqrt(v1);
   mkmat se if _n<=`rowtot', matrix(`matnam'_se); /* automatically replaces vector se */
   matrix rownames `matnam'_se = `names';
   matrix colnames `matnam'_se = `e(depvar)';
   capture drop b1 v1 or se;
end;
*-----------------------------------------------;

use "$root/xba/FDI-worker-data/displacement-probit-worker-sample-$rsample", clear;

memuse; /* nonmf: 33 MB of 500 MB for 2% sample */

drop d_employmtg_1999_1998_*;

memuse; /* nonmf: 30 MB of 500 MB for 2% sample */

if "$par" == "manf" {;
   keep if dwz93g8_3==1;
};

if "$par" == "nonmf" {;
   drop if dwz93g8_3==1;
};

memuse; /* nonmf: 19 MB of 500 MB for 2% sample */


/* merge sector-level variables */
sort wz93_2dig;
merge wz93_2dig using "$root\xba\FDI-worker-data\sector-vars-2000.dta", nokeep;
tab _merge;
keep if _merge==3;
drop _merge;


/* in fdiselct: 
if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
*/

*--------------------------------------------------------------------------------------------;


*--------------------------------------------------------------------------------------------;

global workervars "age age2 ln_wage female emplminor emplother wcollar abiormore apprentice parttime";
global lagvars    "lag_ln_wage lag_nemp";

tsunab plantvars: east nemp dwz93g8_2-dwz93g8_8 p_* plantfe;
global plantvars "`plantvars'";

tsunab sectorvars: imp_* exp_* impinp_*;
global sectorvars "`sectorvars'";

tsunab nonustanvars: $workervars $plantvars $sectorvars $lagvars;
global nonustanvars "`nonustanvars'";

*---------------------------------------------------------------------------------------------;
* Note: Ustan vars fixdasst (capital stock), turnover (output) and value-added in p.c. terms  ;
* par_fixdasst, par_turnover and par_valueadd are in thsd of Euros and are already deflated!! ;
* par_employment is in plain numbers, i.e. NOT in thousands !!!                               ;
*---------------------------------------------------------------------------------------------;
*tsunab ustanvars: par_turnover* par_employmt* par_fixdasst*;
tsunab ustanvars: par_debtsh_99 par_fixdasstpc_99 par_turnoverpc_99;
global ustanvars "`ustanvars'";

tsunab treatvars: employ* d_employ*;
global treatvars "`treatvars'";

tsunab employmtlvls99: employmt_1999_???; /* regions 3-digit code (APC, CEE etc), world-wide 2-digit (WW) */
global employmtlvls99 "`employmtlvls99'";
*global employmtlvls99 = regexr("$employmtlvls99","employmt_1999_ALL","");

foreach var of global nonustanvars {;
   gen eWW99_`var' = employmt_1999_WW * `var';
};

tsunab inonustanvars: eWW99*;
global inonustanvars "`inonustanvars'";

*tsunab expansionvars: d_employmtg_1999_1999_*;
*global expansionvars "`expansionvars'";

*--------------------------------------------------------------------------------------------;

/* foreign employment in per capita (in plant) terms */
foreach expovar of global employmtlvls99 {;
   replace `expovar' = `expovar' / lag_nemp;
};

*--------------------------------------------------------------------------------------------;

/* specifications remarks */
/**************************/
/* Remarks:
1) Since Ustan information is only available for FDI workers/plants, cannot use Ustan vars 
   in specifications where FDI status is the treatment.
2) */

/**************************************************************************/
/* sample type 1: MNEs and non-MNEs,  without (!) Ustan vars              */
/* variables displace d_employmtg_1999_1999 $employmtlvls99 $nonustanvars */
/* have been cleaned up in displacement-pscore-sample.do                  */
/**************************************************************************/
*---------------------------------------------------------------------------------------------;

foreach sample in 1 2 {; /* begin of foreach sample */
   
*------------------------------------------------------------------------------------------------;

   foreach het of global hetlist {; /* het */

   preserve;

   if `het'==1 {;
      keep if wcollar == 1; /* white-collar */
   };
   else if `het'==2 {;
      keep if wcollar == 0; /* blue-collar */
   };
   else if `het'==3 {;
      keep if abiormore == 1; /* high-skilled */
   };
   else if `het'==4 {;
      keep if abiormore == 0; /* low-skilled */
   };

*------------------------------------------------------------------------------------------------;

   summ2tex *, c(mean sd N p50) name(summ_s`sample'_het`het') p(tex/$par) replace detail;
   summ2tex * if d_employmt_1999_WW==1, c(mean sd N p50) name(summ_s`sample'_het`het'_MNE) p(tex/$par) replace detail;
   summ2tex * if d_employmt_1999_WW==0, c(mean sd N p50) name(summ_s`sample'_het`het'_nonMNE) p(tex/$par) replace detail;

*------------------------------------------------------------------------------------------------;

   qui count;
   di _newline(2) "Heterogeneous group `het' has `r(N)' observations";

*------------------------------------------------------------------------------------------------;

   foreach spec of global speclist {;
      mat att_`sample'_spec`spec'_het`het'_tbl = J(8,20,.); /* n x m matrix with missing entries: 1 ALL and 7 regions, estimates and diagnostics */
      mat rownames att_`sample'_spec`spec'_het`het'_tbl =  WW APC CEE EMU ODV OIN OWE RCA;
      mat colnames att_`sample'_spec`spec'_het`het'_tbl =  attseparate seattseparate attnotemp seattnotemp r2bef r2aft chiprobbef chiprobaft medbiasbef medbiasaft ntreat ncontrol ftreat ftlost ftpred fcpred rawdisp1 rawdisp0 ols seols;
   };

*------------------------------------------------------------------------------------------------;

   local i = 1;

   foreach region in WW APC CEE EMU ODV OIN OWE RCA {; /* begin of foreach region */

      if `sample' == 2 {; 
      /**************************************************************************/
      /* sample type 2: MNEs only, without (!) Ustan vars                       */
      /* variables displace d_employmtg_2000_1999 $employmtlvls99 $nonustanvars */
      /* have been cleaned up in displacement-pscore-sample.do                  */
      /**************************************************************************/
         gen d_employmtg_2000_1999_`region'_intmrg = (employmtg_2000_1999_`region'>0) & (employmt_1999_`region'>0);
         sum d_employmtg_2000_1999_`region'_intmrg;
         sum d_employmtg_2000_1999_`region';
         rename d_employmtg_2000_1999_`region' d_employmtg_2000_1999_`region'_uncond;
         rename d_employmtg_2000_1999_`region'_intmrg d_employmtg_2000_1999_`region';
         *keep if d_employmt_1999==1; /* keep only workers/plants with positive FDI exposure in pre-T year 1999 */

      };

 
      /* pstest statistics
      r(meanbiasbef) and r(meanbiasaft) the mean absolute standardised bias, 
      r(medbiasbef) and r(medbiasaft) the median absolute standardised bias, 
      r(r2bef) and r(r2aft) the pseudo R2 from probit estimation and 
      r(chiprobbef) and r(chiprobaft) the P-value of the likelihood-ratio test.
      */

      foreach spec of global speclist {; /* begin of foreach spec */

	
	      if `spec'==1 {;
	         global controllist "$employmtlvls99 $workervars";
	      };
	      else if `spec'==2 {;
	         global controllist "$employmtlvls99 $workervars $plantvars";
	      };
	      else if `spec'==3 {;
	         global controllist "$employmtlvls99 $workervars $plantvars $sectorvars";
	      };
	      else if `spec'==4 {;
	         global controllist "$employmtlvls99 $nonustanvars"; 
	      };
 

         di _newline(2) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         di _newline    "**********************************************************************";

      
         logit separate d_employmtg_2000_1999_`region' $controllist, or; 
         di _newline(1) in red "Compute marginal effects 1: Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
   		*est2vec separate_s`sample'_`region'_spec`spec'_het`het', e(r2_p);
         resultsor separate_s`sample'_`region'_spec`spec'_het`het';

         logit d_employmtg_2000_1999_`region' $controllist, or;
         di _newline(1) in red "Compute marginal effects 2: Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         *est2vec logit_s`sample'_`region'_spec`spec'_het`het', e(r2_p);
         resultsor logit_s`sample'_`region'_spec`spec'_het`het';


         di _newline(2) "PSMATCH2";
         di _newline(1) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         di _newline    "**********************************************************************";

         qui predict phat if e(sample), pr;
         sum phat;
         sum d_employmtg_2000_1999_`region' if e(sample);
         scalar pbar = r(mean);
         qui count if (phat>scalar(pbar)) & d_employmtg_2000_1999_`region'==1;
         scalar ntpred = r(N);
         qui count if (phat<=scalar(pbar)) & d_employmtg_2000_1999_`region'==0;
         scalar ncpred = r(N); 
         drop phat;

         cap noi psmatch2 d_employmtg_2000_1999_`region' $controllist, out(separate notemp) logit common caliper(0.01);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',1]=r(att_separate);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',2]=r(seatt_separate);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',3]=r(att_notemp);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',4]=r(seatt_notemp);

   
         /* raw displacement probabilities */   
      	qui sum separate if _treated==1, mean;
   		mat att_`sample'_spec`spec'_het`het'_tbl[`i',17] = r(mean);
   		qui sum separate if _treated==0, mean;
   		mat att_`sample'_spec`spec'_het`het'_tbl[`i',18] = r(mean);
         qui regress separate _treated;
			mat att_`sample'_spec`spec'_het`het'_tbl[`i',19] = _b[_treated];
			mat att_`sample'_spec`spec'_het`het'_tbl[`i',20] = _se[_treated];
   
   
         di _newline(2) "PSTEST";
         di _newline(1) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         di _newline    "**********************************************************************";

         cap noi pstest $controllist, summary;
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',5]=r(r2bef);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',6]=r(r2aft);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',7]=r(chiprobbef);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',8]=r(chiprobaft);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',9]=r(medbiasbef);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',10]=r(medbiasaft);
         qui count if _treated==1;
         scalar N_treat=r(N);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',11]=r(N);
         qui count if _treated==0;
         scalar N_control=r(N);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',12]=r(N);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',13]=scalar(N_treat/(N_treat+N_control));
         qui count if _treated==1 & _support==0;
         scalar ntlost = r(N);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',14]=scalar(ntlost)/scalar(N_treat);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',15]=scalar(ntpred)/scalar(N_treat);
         mat att_`sample'_spec`spec'_het`het'_tbl[`i',16]=scalar(ncpred)/scalar(N_control);

         di _newline(2)    "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++";

         qui count if _treated==1 & _support==1;

         if r(N)==0 {;
      	   di _newline(2) in red "NO TREATED ON COMMON SUPPORT, rbounds CAN NOT BE EXECUTED";
         };

         else if r(N)!=0 {;
            di _newline(2) in red "Rosenbaum bounds for Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
            di _newline(1) in red "Outcome: separation between t and t+1";
            gen delta_separate = separate - _separate if _treated==1 & _support==1;
         	*rbounds delta_separate, gamma(1 (0.01) 1.10);
         	*rbounds delta_separate, gamma(1.1 (0.05) 2);
   
            di _newline(2) in red "Rosenbaum bounds for Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
            di _newline(1) in red "Outcome: not employed in t+1";
            gen delta_notemp = notemp - _notemp if _treated==1 & _support==1;
      		*rbounds delta_notemp, gamma(1 (0.01) 1.10);
      		*rbounds delta_notemp, gamma(1.1 (0.05) 2);

      		drop delta_separate delta_notemp;
         };

         di _newline(2)    "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++";

         outsheet separate notemp socsecid _pscore _treated _weight _support using "$root/!cafe/Xdata/$par/data_sample`sample'_spec`spec'_het`het'_`region'.csv", comma nolabel replace;

         /* save matrices */
         /*****************/
         foreach type in b se e {;
			   matsave logit_s`sample'_`region'_spec`spec'_het`het'_`type', saving p(estmat/$par) t(double) replace;
			   matsave separate_s`sample'_`region'_spec`spec'_het`het'_`type', saving p(estmat/$par) t(double) replace;
         }; /* type */
         
         matsave att_`sample'_spec`spec'_het`het'_tbl, saving p(estmat/$par) t(double) replace;

      }; /* end of foreach spec */

      local i = `i'+1;
   
   }; /* end of foreach region */

*------------------------------------------------------------------------------------------------;

restore;

}; /* end of foreach het */

*------------------------------------------------------------------------------------------------;

}; /* end of foreach sample */

*------------------------------------------------------------------------------------------------;

/******************************************************/
/* sample type 3: MNEs in FDI-Ustan intersection only */
/******************************************************/
/* drop workers/plants that are not in the FDI-Ustan intersection */

keep if fdiustan==1;

*--------------------------------------------------------------------------------------------;
count;
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */
*--------------------------------------------------------------------------------------------;

/* make sure Ustan variables are always defined */
/************************************************/
foreach var of global ustanvars {;
   keep if `var'!=.;
};

gen outputg = (par_turnover_01-par_turnover_00)/par_turnover_00;
keep if outputg!=.;

*---------------------------------------------------------------------------------------------;
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */
count;
local sample = 3;

foreach var of global nonustanvars {;
   gen dHOM99_`var' = par_debtsh_99 * `var';
   gen fHOM99_`var' = par_fixdasstpc_99 * `var';
   gen tHOM99_`var' = par_turnoverpc_99 * `var';
};
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */

tsunab iustanvars: dHOM99* fHOM99* tHOM99*;
global iustanvars "`iustanvars'";

*------------------------------------------------------------------------------------------------;

foreach het of global hetlist {; /* het */

preserve;

if `het'==1 {;
   keep if wcollar == 1; /* white-collar */
};
else if `het'==2 {;
   keep if wcollar == 0; /* blue-collar */
};
else if `het'==3 {;
   keep if abiormore == 1; /* high-skilled */
};
else if `het'==4 {;
   keep if abiormore == 0; /* low-skilled */
};

*------------------------------------------------------------------------------------------------;

summ2tex *, c(mean sd N p50) name(summ_s`sample'_het`het') p(tex/$par) replace detail;

*------------------------------------------------------------------------------------------------;

qui count;
di _newline(2) "Heterogeneous group `het' has `r(N)' observations";

*------------------------------------------------------------------------------------------------;

foreach spec of global speclist {;
   mat att_`sample'_spec`spec'_het`het'_tbl = J(8,20,.); /* n x m matrix with missing entries: 1 ALL and 7 regions, estimates and diagnostics */
   mat rownames att_`sample'_spec`spec'_het`het'_tbl =  WW APC CEE EMU ODV OIN OWE RCA;
   mat colnames att_`sample'_spec`spec'_het`het'_tbl =  attseparate seattseparate attnotemp seattnotemp r2bef r2aft chiprobbef chiprobaft medbiasbef medbiasaft ntreat ncontrol ftreat ftlost ftpred fcpred rawdisp1 rawdisp0 ols seols;
};

*------------------------------------------------------------------------------------------------;

local i = 1;

foreach region in WW APC CEE EMU ODV OIN OWE RCA {; /* begin of foreach region */

   *rename d_employmtg_2000_1999_`region' d_employmtg_2000_1999_`region'_intmrg;
   *rename d_employmtg_2000_1999_`region'_uncond d_employmtg_2000_1999_`region';
      
   foreach spec of global speclist {; /* begin of foreach spec */

      if `spec'==1 {;
	      global controllist "$employmtlvls99 $workervars $plantvars";
	   };
	   else if `spec'==2 {;
	      global controllist "$employmtlvls99 $workervars $plantvars $ustanvars";
	   };
	   else if `spec'==3 {;
	      global controllist "$employmtlvls99 $nonustanvars $ustanvars";
	   };
	   else if `spec'==4 {;
	      global controllist "$employmtlvls99 $nonustanvars $ustanvars $inonustanvars $iustanvars"; 
	   };


      di _newline(2) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
      di _newline    "**********************************************************************";
   
   
      logit separate d_employmtg_2000_1999_`region' $controllist, or; 
	   di _newline(1) in red "Compute marginal effects 1: Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
	   *est2vec separate_s`sample'_`region'_spec`spec'_het`het', e(r2_p);
	   resultsor separate_s`sample'_`region'_spec`spec'_het`het';
	
	   logit d_employmtg_2000_1999_`region' $controllist, or;
	   di _newline(1) in red "Compute marginal effects 2: Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
	   *est2vec logit_s`sample'_`region'_spec`spec'_het`het', e(r2_p);
	   resultsor logit_s`sample'_`region'_spec`spec'_het`het';


      di _newline(2) "PSMATCH2";
      di _newline(1) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
      di _newline    "**********************************************************************";

      qui predict phat if e(sample), pr;
      sum phat;
      sum d_employmtg_2000_1999_`region' if e(sample);
      scalar pbar = r(mean);
      qui count if (phat>scalar(pbar)) & d_employmtg_2000_1999_`region'==1;
      scalar ntpred = r(N);
      qui count if (phat<=scalar(pbar)) & d_employmtg_2000_1999_`region'==0;
      scalar ncpred = r(N); 
      drop phat;
   
      cap noi psmatch2 d_employmtg_2000_1999_`region' $controllist, out(separate notemp) logit common caliper(0.01);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',1]=r(att_separate);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',2]=r(seatt_separate);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',3]=r(att_notemp);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',4]=r(seatt_notemp);
      
      
     /* raw displacement probabilities */   
		qui sum separate if _treated==1, mean;
		mat att_`sample'_spec`spec'_het`het'_tbl[`i',17] = r(mean);
		qui sum separate if _treated==0, mean;
		mat att_`sample'_spec`spec'_het`het'_tbl[`i',18] = r(mean);
		qui regress separate _treated;
		mat att_`sample'_spec`spec'_het`het'_tbl[`i',19] = _b[_treated];
		mat att_`sample'_spec`spec'_het`het'_tbl[`i',20] = _se[_treated];


      di _newline(2) "PSTEST";
      di _newline(1) "Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
      di _newline    "**********************************************************************";

      cap noi pstest $controllist, summary;
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',5]=r(r2bef);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',6]=r(r2aft);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',7]=r(chiprobbef);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',8]=r(chiprobaft);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',9]=r(medbiasbef);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',10]=r(medbiasaft);
      qui count if _treated==1;
      scalar N_treat=r(N);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',11]=r(N);
      qui count if _treated==0;
      scalar N_control=r(N);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',12]=r(N);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',13]=scalar(N_treat/(N_treat+N_control));
      qui count if _treated==1 & _support==0;
      scalar ntlost = r(N);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',14]=scalar(ntlost)/scalar(N_treat);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',15]=scalar(ntpred)/scalar(N_treat);
      mat att_`sample'_spec`spec'_het`het'_tbl[`i',16]=scalar(ncpred)/scalar(N_control);

      di _newline(2)    "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++";
 
      qui count if _treated==1 & _support==1;

      if r(N)==0 {;
   	   di _newline(2) in red "NO TREATED ON COMMON SUPPORT, rbounds CAN NOT BE EXECUTED";
      };

      else if r(N)!=0 {;
         di _newline(2) in red "Rosenbaum bounds for Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         di _newline(1) in red "Outcome: separation between t and t+1";
         gen delta_separate = separate - _separate if _treated==1 & _support==1;
      	*rbounds delta_separate, gamma(1 (0.01) 1.10);
      	*rbounds delta_separate, gamma(1.1 (0.05) 2);
   
         di _newline(2) in red "Rosenbaum bounds for Sample `sample', Hetgroup `het', Region `region', Specification `spec'";
         di _newline(1) in red "Outcome: not employed in t+1";
         gen delta_notemp = notemp - _notemp if _treated==1 & _support==1;
   		*rbounds delta_notemp, gamma(1 (0.01) 1.10);
   		*rbounds delta_notemp, gamma(1.1 (0.05) 2);

   		drop delta_separate delta_notemp;
      };

      di _newline(2)    "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++";

      outsheet separate notemp socsecid _pscore _treated _weight _support using "$root/!cafe/Xdata/$par/data_sample`sample'_spec`spec'_het`het'_`region'.csv", comma nolabel replace;

      /* save matrices */
      /*****************/
      foreach type in b se e {;
		   matsave logit_s`sample'_`region'_spec`spec'_het`het'_`type', saving p(estmat/$par) t(double) replace;
		   matsave separate_s`sample'_`region'_spec`spec'_het`het'_`type', saving p(estmat/$par) t(double) replace;
      }; /* type */
      
      matsave att_`sample'_spec`spec'_het`het'_tbl, saving p(estmat/$par) t(double) replace;


   }; /* end of foreach spec */

   local i = `i'+1;

}; /* end of foreach region */

*------------------------------------------------------------------------------------------------;

restore;

}; /* end of foreach het */

*------------------------------------------------------------------------------------------------;

log close;
